Package 'submit'

Title: How to Submit R packages and Projects to SwissStatsR
Description: This repository is an example of a SwissStatsR project. It also explains how to submit R packages and R projects to SwissStatsR.org.
Authors: Felix Luginbuhl [aut, cre] (ORCID: <https://orcid.org/0009-0008-6625-2899>), Fachstelle für Statistik Kanton St.Gallen [cph, fnd]
Maintainer: Felix Luginbuhl <[email protected]>
License: GPL (>= 3)
Version: 0.1.0
Built: 2026-05-12 08:08:09 UTC
Source: https://github.com/SwissStatsR/submit

Help Index